﻿/*
 * Licensed under the EUPL, Version 1.1 or – as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence. You may
 * obtain a copy of the Licence at:
 * 
 * http://www.osor.eu/eupl/european-union-public-licence-eupl-v.1.1
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * Licence for the specific language governing permissions and limitations under
 * the Licence.
 */
using System;
using System.Collections.Generic;
using System.Data;

using System.Configuration;

//
// author: AMA – Agência para a Modernização Administrativa IP, PORTUGAL (www.ama.pt)
//
namespace eu.stork.peps.auth.commons
{
    public class CitizenAttributes
    {
        private static readonly CitizenAttributes instance = new CitizenAttributes();

        private Dictionary<int, Attribute> attributesById;
        private Dictionary<string, Attribute> attributesByName;

        private CitizenAttributes()
        {
            PopulatePEPSAttributes();
            return;
        }

        private void PopulatePEPSAttributes()
        {
            char[] attrListSep = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.ATTRIBUTE_SEP).ToCharArray();
            string[] attrList = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.ATTRIBUTE_LIST).Split(attrListSep);
            int i=0;
            attributesById = new Dictionary<int, Attribute>(attrList.Length);
            attributesByName = new Dictionary<string, Attribute>(attrList.Length);
            string now = DateTime.Now.ToString();
            foreach (string attr in attrList)
            {
                string attrNS = ConfigurationSettingsHelper.GetCriticalConfigSetting(attr+CommonConstants.ATTRIBUTE_NS_SUFFIX);
                Attribute attribute = new Attribute(i, attrNS, attr,
                    attr, true, -1, 0, now);
                attributesById.Add(i, attribute);
                attributesByName.Add(attrNS, attribute);
                i++;
            }
        }

        public static CitizenAttributes Instance
        {
            get { return instance; }
        }

        public List<int> GetIds()
        {
            return new List<int>(attributesById.Keys);
        }

        public int GetIdFromName(string name)
        {
            if (!attributesByName.ContainsKey(name))
                return -1;
            return attributesByName[name].Id;
        }
         
        public string GetName(int id)
        {
            return attributesById[id].Name;
        }

        public string GetFriendlyName(int id)
        {
            return attributesById[id].FriendlyName;
        }

        public string GetDescription(int id)
        {
            return attributesById[id].Description;
        }

        public bool HasValueVisualization(int id)
        {
            return attributesById[id].HasValueVisualization;
        }

        public int GetProviderId(int id)
        {
            return attributesById[id].AttributeProviderId;
        }

        public int GetOrderIndex(int id)
        {
            return attributesById[id].OrderIndex;
        }

        public string GetLastUpdate(int id)
        {
            return attributesById[id].LastUpdate;
        }

        private class Attribute
        {
            public Attribute(int id, string name, string friendlyName, string description,
                bool hasValueVisualization, int attrProviderId, int orderIndex, 
                string lastUpdate)
            {
                Id = id;
                Name = name;
                FriendlyName = friendlyName;
                Description = description;
                HasValueVisualization = hasValueVisualization;
                AttributeProviderId = attrProviderId;
                OrderIndex = orderIndex;
                LastUpdate = lastUpdate;
            }
            public int Id
            {
                get;
                set;
            }
            public string Name
            {
                get;
                set;
            }
            public string FriendlyName
            {
                get;
                set;
            }
            public string Description
            {
                get;
                set;
            }
            public bool HasValueVisualization
            {
                get;
                set;
            }
            public int AttributeProviderId
            {
                get;
                set;
            }
            public int OrderIndex
            {
                get;
                set;
            }
            public string LastUpdate
            {
                get;
                set;
            }
            public int SerialNumber
            {
                get;
                set;
            }
        }
    }
}
