﻿/*
 * Licensed under the EUPL, Version 1.1 or – as soon they will be approved by
 * the European Commission - subsequent versions of the EUPL (the "Licence");
 * You may not use this work except in compliance with the Licence. You may
 * obtain a copy of the Licence at:
 * 
 * http://www.osor.eu/eupl/european-union-public-licence-eupl-v.1.1
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the Licence is distributed on an "AS IS" basis, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * Licence for the specific language governing permissions and limitations under
 * the Licence.
 */
using System;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Net;
using System.IO;
using System.Text;
using System.Xml;

using eu.stork.peps.auth.commons;
using eu.stork.peps.auth.engine;
using System.Collections.Generic;

//
// author: AMA – Agência para a Modernização Administrativa IP, PORTUGAL (www.ama.pt)
//
namespace eu.stork.sp
{
    public partial class _Default : System.Web.UI.Page
    {
        bool devTest = false;
        bool reqAll = false;
        bool reqAllMand = false;

       private void PopulateCountryList()
        {
            char[] countrySep = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.COUNTRY_SEP).ToCharArray();
            string[] spepsCountryList = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.SPEPS+CommonConstants.COUNTRY_LIST_SUFFIX).Split(countrySep);
            foreach (string spepsCountry in spepsCountryList)
            {
                countryList.Items.Add(spepsCountry);    
            }
        }

        private void PopulateCPEPSCountryList()
        {
            char[] countrySep = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.COUNTRY_SEP).ToCharArray();
            string[] cpepsCountryList = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.CPEPS + CommonConstants.COUNTRY_LIST_SUFFIX).Split(countrySep);
            foreach (string cpepsCountry in cpepsCountryList)
            {
                DropDownListCPEPSCountry.Items.Add(cpepsCountry);
            }
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            /**
             * Setting SP Provider  Name and SAML Issuer
             */ 
            TextBoxSAMLIssuer.Text = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.SAMLISSUER);
            TextBoxProviderName.Text = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.PROVIDERNAME);
            TextBoxQAALevel.Text = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.QAALEVEL);
            TextBoxReturnURL.Text = ConfigurationSettingsHelper.GetCriticalConfigSetting(CommonConstants.SP_RETURN_URL);
            if (cbListAttributes.Items.Count != 0) return;
            CitizenAttributes citizenAttributes = CitizenAttributes.Instance;
            List<int> ids = citizenAttributes.GetIds();

            //Simplify load page. In case of dev test, "test" querystring must be present
            if (HttpContext.Current.Request.QueryString["test"] != null)
                devTest = true;

            if (!devTest)
            {
                countryList.Visible = true;
            }
            else
            {

                if (HttpContext.Current.Request.QueryString["test"].Equals("2"))
                {
                    TableSAMLTests.Visible = true;
                    string ip = Dns.GetHostAddresses(Dns.GetHostName())[0].ToString();
                }
            }

            foreach (int id in ids)
            {
                cbListAttributes.Items.Add(new ListItem(citizenAttributes.GetDescription(id), id.ToString()));
                cbListRequired.Items.Add(new ListItem(" ", id.ToString()));
            }
            PopulateCountryList();
            PopulateCPEPSCountryList();
        }


        private string GetSAMLRequestB64()
        {
            SAMLRequest request = new SAMLRequest();
            string destination = countryList.SelectedValue + CommonConstants.SPEPS_SUFFIX;
            request.Destination = ConfigurationSettingsHelper.GetCriticalConfigSetting(destination);
            request.AssertionConsumerServiceURL = HttpContext.Current.Request.Form[TextBoxReturnURL.ID];
            request.Country = DropDownListCPEPSCountry.SelectedValue;
            request.ProviderName = HttpContext.Current.Request.Form[TextBoxProviderName.ID];
            request.Issuer = HttpContext.Current.Request.Form[TextBoxSAMLIssuer.ID];
            request.QAALevel = HttpContext.Current.Request.Form[TextBoxQAALevel.ID];
            request.Id = "_" + Guid.NewGuid().ToString();

            CitizenAttributes citizenAttributes = CitizenAttributes.Instance;
            foreach (int id in citizenAttributes.GetIds())
            {
                try
                {
                    if (cbListAttributes.Items.FindByValue(id.ToString()).Selected)
                        request.AddAttribute(id, cbListRequired.Items.FindByValue(id.ToString()).Selected);
                }
                catch(Exception)
                {                    
                }
            }

            SAMLEngine samlEngine = SAMLEngine.Instance;
            samlEngine.Init(HttpContext.Current.Server.MapPath(".") + "/bin/");
            XmlDocument xml = samlEngine.GenerateRequest(request);

            // test TC.SAML.7
            if (CheckBoxXMLMalFormed.Checked)
            {
                StringWriter sw = new StringWriter();
                XmlTextWriter tx = new XmlTextWriter(sw);
                xml.WriteTo(tx);
                string xmltest = sw.ToString();
                xmltest = xmltest.Replace("</", "<</");
                return Convert.ToBase64String(Encoding.UTF8.GetBytes(xmltest));
            }
            else
            {
                // test TC.SAML.10
                if (CheckBoxChangeSignedContent.Checked)
                {
                    XmlElement root = xml.DocumentElement;
                    XmlNodeList nodeList = root.GetElementsByTagName("stork:RequestedAttribute");
                    XmlAttributeCollection coll = nodeList[0].Attributes;
                    for (int i = 0; i < coll.Count; i++)
                    {
                        if (coll.Item(i).Name.Equals("isRequired"))
                        {
                            if ("True".Equals(coll.Item(i).Value))
                                coll.Item(i).Value = "False";
                            else
                                coll.Item(i).Value = "True";
                            break;
                        }
                    }
                }

                return Convert.ToBase64String(Encoding.UTF8.GetBytes(xml.OuterXml));
            }            
        }

        protected void do_POST(object sender, EventArgs e)
        {
            int i;
            bool hasSelectedItems = false;
            for (i = 0; i < cbListAttributes.Items.Count; i++)
                if (cbListAttributes.Items[i].Selected)
                {
                    hasSelectedItems = true;
                    break;
                }
            if (!((HttpContext.Current.Request.QueryString["test"] != null) &&
                (HttpContext.Current.Request.QueryString["test"].Equals("2"))))
            {
                if (!hasSelectedItems)
                {
                    Label l = new Label();
                    l.Text = "<script language='javascript'>" + Environment.NewLine + "window.alert('Tem que seleccionar pelo menos um atributo!')</script>";
                    Page.Controls.Add(l);
                    return;
                }
            }

            //string destinationUrl   = host.Value;
            string samlRequestField = ConfigurationSettingsHelper.GetCriticalConfigSetting("samlRequestField"),
            relayStateField         = ConfigurationSettingsHelper.GetCriticalConfigSetting("relayStateField"),
            countryField            = ConfigurationSettingsHelper.GetCriticalConfigSetting("countryField");

            string postForm = string.Empty;

            if ((HttpContext.Current.Request.QueryString["test"] != null) &&
                HttpContext.Current.Request.QueryString["test"].Equals("2"))
            {
                if (CheckBoxSendTwice.Checked &&
                    !string.IsNullOrEmpty(TextBoxSAMLrequest.Text))
                {
                    // test TC.SAML.8
                    postForm = WebUtils.PreparePOSTForm(
                        samlRequestField, relayStateField, countryField,
                        TextBoxSAMLrequest.Text, "State information to be persisted across", countryList.SelectedValue, DropDownListCPEPSCountry.SelectedValue);
                }
                else if (CheckBoxNoSAMLv2Schema.Checked &&
                        !string.IsNullOrEmpty(TextBoxNotSAMLv2Schema.Text))
                {
                    // test TC.SAML.11
                    postForm = WebUtils.PreparePOSTForm(
                        samlRequestField, relayStateField, countryField,
                        TextBoxNotSAMLv2Schema.Text, "State information to be persisted across", countryList.SelectedValue, DropDownListCPEPSCountry.SelectedValue);
                }
                else if (CheckBoxInvalidAttributes.Checked &&
                    !string.IsNullOrEmpty(TextBoxInvalidAttributes.Text))
                {
                    // test TC.SAML.13
                    postForm = WebUtils.PreparePOSTForm(
                        samlRequestField, relayStateField, countryField,
                        TextBoxInvalidAttributes.Text, "State information to be persisted across", countryList.SelectedValue, DropDownListCPEPSCountry.SelectedValue);
                }
                else
                {
                    string samlRequestB64 = GetSAMLRequestB64();
                    postForm = WebUtils.PreparePOSTForm(
                        samlRequestField, relayStateField, countryField,
                        samlRequestB64, "State information to be persisted across", countryList.SelectedValue, DropDownListCPEPSCountry.SelectedValue);
                }
            }
            else
            {
                string samlRequestB64 = GetSAMLRequestB64();
                postForm = WebUtils.PreparePOSTForm(
                    samlRequestField, relayStateField, countryField, samlRequestB64,
                    "State information to be persisted across", countryList.SelectedValue, DropDownListCPEPSCountry.SelectedValue);
            }

            this.Page.Controls.Add(new LiteralControl(postForm));
        }
        protected void CheckBoxSendTwice_CkeckedChanged(object sender, EventArgs e)
        {
            TextBoxSAMLrequest.Visible = CheckBoxSendTwice.Checked;
            LinkButtonGenerateRequest.Visible = CheckBoxSendTwice.Checked;
        }

        protected void GenerateRequest(object sender, EventArgs e)
        {
            TextBoxSAMLrequest.Text = GetSAMLRequestB64();
        }

        protected void CheckBoxNoSAMLv2Schema_OnCheckedChanged(object sender, EventArgs e)
        {
            TextBoxNotSAMLv2Schema.Visible = CheckBoxNoSAMLv2Schema.Checked;
        }

        protected void CheckBoxInvalidAttributes_OnCheckedChanged(object sender, EventArgs e)
        {
            TextBoxInvalidAttributes.Visible = CheckBoxInvalidAttributes.Checked;
        }

        protected void LinkButton1_Click(object sender, EventArgs e)
        {
            CitizenAttributes citizenAttributes = CitizenAttributes.Instance;
            reqAllMand = !reqAllMand;
            foreach (int id in citizenAttributes.GetIds())
            {
                try
                {
                    if (reqAllMand)
                    {
                        cbListRequired.Items.FindByValue(id.ToString()).Selected = true;
                        cbListAttributes.Items.FindByValue(id.ToString()).Selected = true; 
                    }
                    else
                    {
                        cbListRequired.Items.FindByValue(id.ToString()).Selected = false;
                    }
                }
                catch (Exception)
                {

                }
            }
        }

        protected void LinkButtonRequestAllAttr_Click(object sender, EventArgs e)
        {
            CitizenAttributes citizenAttributes = CitizenAttributes.Instance;
            reqAll = !reqAll;
            foreach (int id in citizenAttributes.GetIds())
            {
                try
                {
                    if (reqAll)
                    {
                        cbListAttributes.Items.FindByValue(id.ToString()).Selected = true;
                    }
                    else
                    {
                        cbListRequired.Items.FindByValue(id.ToString()).Selected = false;
                        cbListAttributes.Items.FindByValue(id.ToString()).Selected = false;
                    }
                 }
                catch (Exception)
                {

                }
            }
        }

        protected void CheckBoxAllRequired_CheckedChanged(object sender, EventArgs e)
        {
            CitizenAttributes citizenAttributes = CitizenAttributes.Instance;
            foreach (int id in citizenAttributes.GetIds())
            {
                try
                {
                    if (CheckBoxAllRequired.Checked)
                    {
                        cbListRequired.Items.FindByValue(id.ToString()).Selected = true;
                        cbListAttributes.Items.FindByValue(id.ToString()).Selected = true;
                    }
                    else
                    {
                        cbListRequired.Items.FindByValue(id.ToString()).Selected = false;
                    }}
                catch (Exception)
                {

                }
            }
        }

        protected void CheckBoxAllAttr_CheckedChanged(object sender, EventArgs e)
        {
            CitizenAttributes citizenAttributes = CitizenAttributes.Instance;
            foreach (int id in citizenAttributes.GetIds())
            {
                try
                {
                    if (CheckBoxAllAttr.Checked)
                    {
                        cbListAttributes.Items.FindByValue(id.ToString()).Selected = true;
                    }
                    else
                    {
                        cbListRequired.Items.FindByValue(id.ToString()).Selected = false;
                        cbListAttributes.Items.FindByValue(id.ToString()).Selected = false;
                    }
                }
                catch (Exception)
                {

                }
            }
        }
    }
}
